﻿using API.Controllers;
using Dto;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging.Abstractions;
using Moq;
using Shared;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using TestAPI.Extensions;

namespace TestAPI
{
    public class ParagraphsUnitTest

    {
        private readonly Mock<IParagraphService<ParagraphDTO>> paragraphService;

        public ParagraphsUnitTest()
        {
            paragraphService = new Mock<IParagraphService<ParagraphDTO>>();
        }

        [Fact]
        public void GetParagraphsListSuccess()
        {
            var paragraphsList = GetParagraphsData();
            paragraphService.Setup(x => x.GetParagraphs(1, 4, 0))
                .Returns(paragraphsList);
            var ParagraphsController = new ParagraphsController(paragraphService.Object, new NullLogger<ParagraphsController>());

            var paragraphsResult = ParagraphsController.GetParagraphs(1, 4, 0);

            if (paragraphsResult is OkObjectResult okObjectResult)
            {
                var valeur = okObjectResult.Value;

                Assert.NotNull(valeur);
                Assert.Equal(GetParagraphsData().ToString(), valeur.ToString());
                Assert.True(paragraphsList.SequenceEqual(valeur as IEnumerable<ParagraphDTO>, new ParagraphIdEqualityComparer()));

            }

        }

        [Fact]
        public void GetParagraphsListFail()
        {
            paragraphService.Setup(x => x.GetParagraphs(1, 4, 0))
                .Returns(new List<ParagraphDTO>());
            var ParagraphsController = new ParagraphsController(paragraphService.Object, new NullLogger<ParagraphsController>());

            var paragraphsResult = ParagraphsController.GetParagraphs(1, 4, 0);

            if (paragraphsResult is StatusCodeResult statusCodeResult && statusCodeResult.StatusCode == 204)

            {

                Assert.IsNotType<OkObjectResult>(paragraphsResult);
            }

        }



































        private List<ParagraphDTO> GetParagraphsData()
        {
            List<ParagraphDTO> paragraphsData = new List<ParagraphDTO>(4)
            {
                new (0,"Titre 1","Le contenu","Les infos de ce paragraphes sont ","Select * from C#","Le commentaire",1),
                new (1,"Le titre","pas contenu","Pas d'infos ici ","Delete * from Earth","Miam",2),
                new (2,"Ceci n'est pas un titre","Certainement hmmm","OUOOOOO ","Autocommit = {true}","First",1),
                new ("Title","Content","Je ne parle pas anglais","Select select from select","Mais qui est ce commentaire",3),


            };
            return paragraphsData;
        }

    }



}

